@@ -1,5 +1,8 @@
 from pdb import set_trace as T
 import numpy as np
+import logging
+
+from ordered_set import OrderedSet
 
 from nmmo import core
 from nmmo.lib import material
@@ -13,8 +16,10 @@ class Map:
    '''
    def __init__(self, config, realm):
       self.config = config
+      self._repr  = None
+      self.realm  = realm
 
-      sz          = config.TERRAIN_SIZE
+      sz          = config.MAP_SIZE
       self.tiles  = np.zeros((sz, sz), dtype=object)
 
       for r in range(sz):
@@ -32,12 +37,15 @@ class Map:
    @property
    def repr(self):
       '''Flat matrix of tile material indices'''
-      return [[t.mat.index for t in row] for row in self.tiles]
+      if not self._repr:
+          self._repr = [[t.mat.index for t in row] for row in self.tiles]
+
+      return self._repr
 
    def reset(self, realm, idx):
       '''Reuse the current tile objects to load a new map'''
       config = self.config
-      self.updateList = set()
+      self.updateList = OrderedSet()
 
       path_map_suffix = config.PATH_MAP_SUFFIX.format(idx)
       fPath = os.path.join(config.PATH_CWD, config.PATH_MAPS, path_map_suffix)
@@ -57,12 +65,19 @@ class Map:
 
    def step(self):
       '''Evaluate updatable tiles'''
+      if self.config.LOG_MILESTONES and self.realm.quill.milestone.log_max(f'Resource_Depleted', len(self.updateList)) and self.config.LOG_VERBOSE:
+         logging.info(f'RESOURCE: Depleted {len(self.updateList)} resource tiles')                           
+
+
       for e in self.updateList.copy():
-         if e.static:
+         if not e.depleted:
             self.updateList.remove(e)
          e.step()
 
-   def harvest(self, r, c):
+   def harvest(self, r, c, deplete=True):
       '''Called by actions that harvest a resource tile'''
-      self.updateList.add(self.tiles[r, c])
-      return self.tiles[r, c].harvest()
+
+      if deplete:
+          self.updateList.add(self.tiles[r, c])
+
+      return self.tiles[r, c].harvest(deplete)
