@@ -25,9 +25,11 @@ class OverlayRegistry:
               'wilderness': Wilderness}
 
 
-   def init(self):
+   def init(self, *args):
+      self.initialized = True
       for cmd, overlay in self.overlays.items():
-         self.overlays[cmd] = overlay(self.config, self.realm)
+         self.overlays[cmd] = overlay(self.config, self.realm, *args)
+      return self
 
    def step(self, obs, pos, cmd):
       '''Per-tick overlay updates
@@ -38,7 +40,6 @@ class OverlayRegistry:
           cmd: User command returned by the client
       '''
       if not self.initialized:
-          self.initialized = True
           self.init()
 
       self.realm.overlayPos = pos
@@ -63,7 +64,7 @@ class Overlay:
       self.config     = config
       self.realm      = realm
 
-      self.size       = config.TERRAIN_SIZE
+      self.size       = config.MAP_SIZE
       self.values     = np.zeros((self.size, self.size))
 
    def update(self, obs):
@@ -92,7 +93,7 @@ class Skills(Overlay):
       for entID, agent in self.realm.realm.players.items():
          r, c = agent.base.pos
 
-         skillLvl  = (agent.skills.fishing.level + agent.skills.hunting.level)/2.0
+         skillLvl  = (agent.skills.food.level.val + agent.skills.water.level.val)/2.0
          combatLvl = combat.level(agent.skills)
 
          if skillLvl == 10 and combatLvl == 3:
@@ -127,7 +128,7 @@ class Skills(Overlay):
 class Counts(Overlay):
    def __init__(self, config, realm, *args):
       super().__init__(config, realm)
-      self.values = np.zeros((self.size, self.size, config.NPOP))
+      self.values = np.zeros((self.size, self.size, config.PLAYER_POLICIES))
 
    def update(self, obs):
       '''Computes a count-based exploration map by painting
@@ -140,7 +141,7 @@ class Counts(Overlay):
    def register(self, obs):
       colors    = self.realm.realm.players.palette.colors
       colors    = np.array([colors[pop].rgb
-            for pop in range(self.config.NPOP)])
+            for pop in range(self.config.PLAYER_POLICIES)])
 
       colorized = self.values[:, :, :, None] * colors / 255
       colorized = np.sum(colorized, -2)
