@@ -4,7 +4,6 @@ import numpy as np
 from signal import signal, SIGINT
 import sys, os, json, pickle, time
 import threading
-import ray
 
 from twisted.internet import reactor
 from twisted.internet.task import LoopingCall
@@ -76,14 +75,13 @@ class GodswordServerProtocol(WebSocketServerProtocol):
         packet['npc']        = data['npc']
         packet['pos']        = data['pos']
         packet['wilderness'] = data['wilderness']
-
-        config = data['config']
-
+        packet['market']     = data['market']
+        
         print('Is Connected? : {}'.format(self.isConnected))
         if not self.sent_environment:
             packet['map']    = data['environment']
-            packet['border'] = config.TERRAIN_BORDER
-            packet['size']   = config.TERRAIN_SIZE
+            packet['border'] = data['border']
+            packet['size']   = data['size']
 
         if 'overlay' in data:
            packet['overlay'] = data['overlay']
